package nodes

import (
	"log"

	"github.com/jinzhu/gorm"
	"github.com/shirou/gopsutil/cpu"
	"github.com/shirou/gopsutil/disk"
	"github.com/shirou/gopsutil/load"
	"github.com/shirou/gopsutil/mem"
)

// PerformanceLog keeps track of performance history
type PerformanceLog struct {
	gorm.Model

	Load1          float64
	Load5          float64
	Load15         float64
	DiskSpaceUsage float64
	Memory         float64
}

// Log creates a record for all important metrics used as
func Log() error {
	performanceLog := PerformanceLog{}

	// Load
	loadStats, err := load.Avg()
	if err != nil {
		return err
	}

	performanceLog.Load1 = loadStats.Load1
	performanceLog.Load5 = loadStats.Load5
	performanceLog.Load15 = loadStats.Load15

	// Memory
	memoryStat, err := mem.VirtualMemory()
	if err != nil {
		return err
	}
	performanceLog.Memory = memoryStat.UsedPercent / 100.0

	// Disk space
	diskUsage, err := disk.Usage("/srv")
	if err != nil {
		return err
	}
	performanceLog.DiskSpaceUsage = diskUsage.UsedPercent / 100.0

	return nil
}

// Index returns number from 0 to 1 where 0 means least loaded and 1 maximally loaded.
// It uses history of last 72 hours
func Index() (float64, error) {
	// Number of CPUs
	cpus, err := cpu.Counts(true)
	if err != nil {
		return 1.0, err
	}
	log.Println(cpus)

	return 1.0, err
}
